You are viewing a plain text version of this content. The canonical link for it is here.
Posted to axis-cvs@ws.apache.org by th...@apache.org on 2007/06/19 15:26:23 UTC

svn commit: r548721 - /webservices/axis2/trunk/java/modules/kernel/src/org/apache/axis2/deployment/repository/util/WSInfo.java

Author: thilina
Date: Tue Jun 19 06:26:22 2007
New Revision: 548721

URL: http://svn.apache.org/viewvc?view=rev&rev=548721
Log:
adding constant to make the workaround looks better

Modified:
    webservices/axis2/trunk/java/modules/kernel/src/org/apache/axis2/deployment/repository/util/WSInfo.java

Modified: webservices/axis2/trunk/java/modules/kernel/src/org/apache/axis2/deployment/repository/util/WSInfo.java
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/java/modules/kernel/src/org/apache/axis2/deployment/repository/util/WSInfo.java?view=diff&rev=548721&r1=548720&r2=548721
==============================================================================
--- webservices/axis2/trunk/java/modules/kernel/src/org/apache/axis2/deployment/repository/util/WSInfo.java (original)
+++ webservices/axis2/trunk/java/modules/kernel/src/org/apache/axis2/deployment/repository/util/WSInfo.java Tue Jun 19 06:26:22 2007
@@ -26,9 +26,10 @@
 
     public static final int TYPE_SERVICE = 0;
     public static final int TYPE_MODULE = 1;
+    public static final int TYPE_CUSTOM_DEPLOYER_SERVICE = 2;
 
     /**
      * To check whether the file is a module or a servise
      */
     private int type = TYPE_SERVICE;
 
@@ -52,7 +53,7 @@
         this.deployer = deployer;
         //TODO: This is a temporary fix for the hot update in custom deployers
         if (!(deployer instanceof ServiceDeployer)) {
-           this.type=2;
+           this.type=TYPE_CUSTOM_DEPLOYER_SERVICE;
         }
     }
 



---------------------------------------------------------------------
@@ -26,9 +26,10 @@
 
     /**
-     * To check whether the file is a module or a servise
+     * To check whether the file is a module or a service
      */
     private int type = TYPE_SERVICE;
To unsubscribe, e-mail: axis-cvs-unsubscribe@ws.apache.org
For additional commands, e-mail: axis-cvs-help@ws.apache.org